@@ -1,6 +1,23 @@
 svydesign<-function(ids,probs=NULL,strata=NULL,variables=NULL, fpc=NULL,
                     data=NULL, nest=FALSE, check.strata=!nest,weights=NULL){
 
+    ## less memory-hungry version for sparse tables
+    interaction<-function (..., drop = TRUE) {
+        args <- list(...)
+        narg <- length(args)
+        if (narg == 1 && is.list(args[[1]])) {
+            args <- args[[1]]
+            narg <- length(args)
+        }
+        
+        ls<-sapply(args,function(a) length(levels(a)))
+        ans<-do.call("paste",c(lapply(args,as.character),sep="."))
+        ans<-factor(ans)
+        return(ans)
+        
+    }
+
+    
      if(inherits(ids,"formula")) {
 	 mf<-substitute(model.frame(ids,data=data))   
 	 ids<-eval.parent(mf)
@@ -55,14 +72,14 @@ svydesign<-function(ids,probs=NULL,strata=NULL,variables=NULL, fpc=NULL,
      if (nest && NCOL(ids)>1){
       N<-ncol(ids)
       for(i in 2:(N)){
-         ids[,i]<-do.call("interaction",ids[,1:i,drop=TRUE])
+          ids[,i]<-do.call("interaction", ids[,1:i,drop=TRUE])
       }
     }
      ## force clusters nested in strata
      if (nest && !is.null(strata) && NCOL(ids)){
        N<-NCOL(ids)
        for(i in 1:N)
-         ids[,i]<-do.call("interaction", list(strata, ids[,i],drop=TRUE))
+         ids[,i]<-do.call("interaction", list(strata, ids[,i]))
      }
 
     ## check if clusters nested in strata 
@@ -804,3 +821,4 @@ summary.svymle<-function(object,stderr=c("robust","model"),...){
     if (is.null(getOption("survey.lonely.psu")))
         options(survey.lonely.psu="fail")
 }
+
